globvars <- new.env()

# PPM_MIN
#
# Minimal ppm value for 1H NMR to consider in the processing step and then to store in the specMat object
# Default value = 0.5
globvars$PPM_MIN <- -0.5

# PPM_MAX
#
# Maximal ppm value for 1H NMR to consider in the processing step and then to store in the specMat object
# Default value = 11
globvars$PPM_MAX <- 11

# PPM_MIN_13C
#
# Minimal ppm value for 13C NMR to consider in the processing step and then to store in the specMat object
# Default value = 0
globvars$PPM_MIN_13C <- 0

# PPM_MAX_13C
#
# Maximal ppm value for 13C NMR to consider in the processing step and then to store in the specMat object
# Default value = 200
globvars$PPM_MAX_13C <- 200

# LOGFILE
#
# Default log file - Default value = stderr()
globvars$LOGFILE <- ""
